#ifndef __FD_ACTIONS_H__
#define __FD_ACTIONS_H__

#include <glib-object.h>
#include <gio/gio.h>

G_BEGIN_DECLS

typedef enum {
    FD_ACTION_NONE = 0,
    FD_ACTION_LOGOUT,
    FD_ACTION_SWITCH_USER,
    FD_ACTION_SUSPEND,
    FD_ACTION_HIBERNATE,
    FD_ACTION_REBOOT,
    FD_ACTION_POWEROFF,
    FD_ACTION_SCREENSAVER_LOCK,
} FdActionTypes;

/* 动作场景标识，例如在指定场景下打开或者关闭某些功能 */
typedef enum {
    FD_ACTION_RUN_NONE      = 0,
    FD_ACTION_RUN_GUI       = 1 << 0,       //图形用户界面相关场景
    FD_ACTION_RUN_COMMAND   = 1 << 1,       //命令行场景
    FD_ACTION_RUN_DBUS      = 1 << 2,       //dbus通信
    FD_ACTION_RUN_SHORTCUT  = 1 << 3,       //快捷键

    FD_ACTION_RUN_ALL       = FD_ACTION_RUN_GUI |
                              FD_ACTION_RUN_COMMAND |
                              FD_ACTION_RUN_DBUS |
                              FD_ACTION_RUN_SHORTCUT,
} FdActionRunFlags;

gboolean
fd_action_is_disabled (FdActionTypes action_type, FdActionRunFlags run_flag);
gboolean
fd_action_is_disabled_by_name (const gchar *name, FdActionRunFlags run_flag);

const gchar *
fd_action_get_name (FdActionTypes action_type);

const gchar *
fd_action_get_display_name (FdActionTypes action_type);

G_END_DECLS

#endif
